@@ -17,8 +17,8 @@ describe 'tripleo::host::sriov' do
       end
 
       it 'configures numvfs' do
-        is_expected.to contain_sriov_vf_config('eth0:4').with( :ensure => 'present' )
-        is_expected.to contain_sriov_vf_config('eth1:5').with( :ensure => 'present')
+        is_expected.to contain_sriov_vf_config('eth0:4')
+        is_expected.to contain_sriov_vf_config('eth1:5')
         is_expected.to contain_tripleo__host__sriov__numvfs_persistence('persistent_numvfs').with(
           :vf_defs        => ['eth0:4','eth1:5'],
           :content_string => "#!/bin/bash\n"
